@@ -12,7 +12,7 @@ def require_params(*args, **kwargs):
             missing = []
             req_args = self.query if self.method == 'get' else self.body
             for param in required_params:
-                if param not in req_args:
+                if param not in req_args or req_args[param] is None:
                     missing.append(param)
             if missing:
                 self.error(400, 'Missing required parameter(s) ({0})'.format(', '.join(missing)))
