@@ -7,4 +7,8 @@ class ApiError(Exception):
         self.message = message
 
     def __str__(self):
-        return xjson.dumps(dict(code=self.code, message=self.message))
\ No newline at end of file
+        return xjson.dumps(dict(code=self.code, message=self.message))
+
+
+class SettingsError(Exception):
+    pass
\ No newline at end of file
